# insardev

Core interferometric processing and analysis tools for the InSAR.dev ecosystem.

## License

See [LICENSE](./LICENSE) for full terms.  

## No Warranty

This software is provided “as is”, without warranty of any kind, express or implied,  
including but not limited to the warranties of merchantability, fitness for a particular  
purpose, and non-infringement. In no event shall the authors or copyright holders be  
liable for any claim, damages or other liability, whether in an action of contract, tort  
or otherwise, arising from, out of or in connection with the software or the use or other  
dealings in the software.

## Support

Official support and priority issue handling are available exclusively to **InSAR.dev Professional** members on [Patreon](https://www.patreon.com/pechnikov/).
